---
sidebar_label: data_structure
title: soil.data_structure
---

This module implements a Data Structure

## DataStructure Objects

```python
class DataStructure()
```

Data Structure class

#### get\_data

```python
 | get_data(**kwargs: Dict[str, Any]) -> Dict[Union[str, int], Any]
```

Invoke the get_data() method from the data structure in the cloud.

